@@ -3,6 +3,4 @@ from .adds.add_positions import positions
 from .adds.parsing import parsing
 from .adds.add_lr import lr
 from .adds.annotation import annotation
-from .adds.add_cpdb import cpdb
-from .adds.auto_annotate import auto_annotate
-from .adds.add_loupe_clusters import add_loupe_clusters
\ No newline at end of file
+from .adds.add_labels import labels
