@@ -10,6 +10,8 @@ def deconvolution_plot(
     library_id: str = None,
     use_label: str = "louvain",
     cluster: [int,str] = None,
+    celltype: str = None,
+    celltype_threshold: float = 0,
     data_alpha: float = 1.0,
     threshold: float = 0.5,
     cmap: str = "tab20",
@@ -18,7 +20,6 @@ def deconvolution_plot(
     spot_size: Union[float, int] = 10,
     show_axis: bool = False,
     show_legend: bool = True,
-    dpi: int = 180,
     cropped: bool = True,
     margin: int = 100,
     name: str = None,
@@ -51,8 +52,6 @@ def deconvolution_plot(
         Show axis or not.
     show_legend
         Show legend or not.
-    dpi
-        Set dpi as the resolution for the plot.
     show_trajectory
         Show the spatial trajectory or not. It requires stlearn.spatial.trajectory.pseudotimespace.
     show_subcluster
@@ -68,7 +67,7 @@ def deconvolution_plot(
     Nothing
     """
 
-    plt.rcParams['figure.dpi'] = dpi
+    #plt.rcParams['figure.dpi'] = dpi
     
     imagecol = adata.obs["imagecol"]
     imagerow = adata.obs["imagerow"]
@@ -79,12 +78,16 @@ def deconvolution_plot(
 
     tmp = label.sum(axis=1)
 
-    label_filter = label.loc[tmp[tmp>np.quantile(tmp,threshold)].index]
+    label_filter = label.loc[tmp[tmp>=np.quantile(tmp,threshold)].index]
+
     
     if cluster is not None:
         base = adata.obs[adata.obs[use_label]==str(cluster)][["imagecol","imagerow"]]
     else:   
         base =  adata.obs[["imagecol","imagerow"]]
+
+    if celltype is not None:
+        base = base.loc[adata.obs_names[adata.obsm["deconvolution"][celltype]>celltype_threshold]]
     
     label_filter_ = label_filter[base.index]
 
@@ -145,7 +148,7 @@ def deconvolution_plot(
             name = use_label
 
     if output is not None:
-        fig.savefig(output + "/" + name + ".png", dpi=dpi,
+        fig.savefig(output + "/" + name, dpi=plt.figure().dpi,
                     bbox_inches='tight', pad_inches=0)
 
     
