@@ -27,6 +27,7 @@ def tree_plot(
     output: str = None,
     dpi: int = 180,
     show_all: bool = False,
+    show_plot: bool = True,
     copy: bool = False,
 ) -> Optional[AnnData]:
 
@@ -73,11 +74,11 @@ def tree_plot(
     for node in G.nodes:
         if node == 9999:
             break
-        tmp_img = _generate_image(adata,library_id,sub_cluster=node,zoom=zoom, spot_size=spot_size,fontsize=fontsize,show_all=show_all)
+        tmp_img = _generate_image(adata,library_id,sub_cluster=node,zoom=zoom, spot_size=spot_size,fontsize=fontsize,show_all=show_all,use_label=use_label)
 
         G.nodes[node]['image'] = tmp_img
 
-    plt.rcParams['figure.dpi'] = dpi
+    #plt.rcParams['figure.dpi'] = dpi
     pos = hierarchy_pos(G,9999) 
     fig=plt.figure(figsize=figsize)
     a= plt.subplot(111)
@@ -118,9 +119,13 @@ def tree_plot(
         name = use_label
 
     if output is not None:
-        fig.savefig(output + "/" + name + ".png", dpi=dpi,
+        fig.savefig(output + "/" + name, dpi=plt.figure().dpi,
                     bbox_inches='tight', pad_inches=0)
 
+    if show_plot == True:
+        plt.show()
+
+
 
 
 
