@@ -74,7 +74,7 @@ def Read10X(
     
     from scanpy import read_visium
     adata = read_visium(path, genome=None,
-     count_file='filtered_feature_bc_matrix.h5',
+     count_file=count_file,
       library_id=None,
        load_images=True)
     adata.var_names_make_unique()
@@ -180,7 +180,7 @@ def ReadSlideSeq(
     max_size = np.max([adata.obs["imagecol"].max(),adata.obs["imagerow"].max()])
     max_size = int(max_size + 0.1*max_size)
 
-    image = Image.new('RGB', (max_size, max_size), (255, 255, 255))
+    image = Image.new('RGB', (max_size, max_size), (0, 0, 0))
     imgarr = np.array(image)
 
     if library_id is None:
